'use strict';

/**
 * Created by Dio on 2016/9/3.
 */
var React = require('react');
var _ = require('lodash');
var DefaultParams = require('./DefaultParams');
var DefaultParser = require('./DefaultParser');
var DefaultHandler = require('./DefaultHandler');
var DefaultActions = require('./DefaultActions');
var TreeUtils = require('../../utils/TreeUtils');
var JsPluginUtils = require('../../utils/JsPluginUtils');
var ADDR = require('../BaseHost');

//是否存在运行参数表达式
var hasParamPatten = function hasParamPatten(str) {
    var patten = new RegExp('!\{.+}', 'gm');
    return patten.test(str);
};
//存放原始数据的View，界面不可见。
var EmptyView = React.createClass({
    displayName: 'EmptyView',

    render: function render() {
        return null;
    }
});

//特别的parser动态注册
var defaultCustomParser = function defaultCustomParser(options) {
    var _options$item = options.item,
        item = _options$item === undefined ? {} : _options$item;

    var UIComponent;
    if (item.uitype === "ChartWidget") {
        try {
            UIComponent = require('../widgets/ChartWidget');
        } catch (e) {
            window.alert("缺少echart引用，详情请见F12控制台");
            console.error("##缺少echart引用，请在index.html里加入以下内容##\n<script src=\"//static.yonyouccs.com/echarts/3.2.3/echarts.min.js\"></script>");
        }
    }
    return UIComponent;
};
//缓存权限验证的数据
var authorityViewsCache = {};
//缺省的权限验证逻辑
var defaultViewAuthValid = function defaultViewAuthValid(options) {
    var _options$item2 = options.item,
        item = _options$item2 === undefined ? {} : _options$item2,
        appCode = options.appCode,
        pageCode = options.pageCode;

    var uikey = item.uikey;
    var cacheKey = "view_auth_" + appCode + "_" + pageCode;
    if (!authorityViewsCache[cacheKey]) {
        authorityViewsCache[cacheKey] = getAuthorityViews(appCode, pageCode);
    }
    var btn = authorityViewsCache[cacheKey] && authorityViewsCache[cacheKey].length > 0 ? _.find(authorityViewsCache[cacheKey], ['btnCode', uikey]) : null;
    return btn ? btn : { enable: true, viewMode: 'hidden' };
};
//缓存视图权限(按钮)
var getAuthorityViews = function getAuthorityViews(appCode, pageCode) {
    try {
        if (!window.top || !window.top.getAuthorityButtons) {
            return [];
        } else {
            //getAuthorityButtons内部做了缓存
            return window.top.getAuthorityButtons(appCode, pageCode);
        }
    } catch (e) {
        console.error(e);
        return [];
    }
};
//格式化URL路径
function formatUrlPath(baseHost, url) {
    if (baseHost && url) {
        if (_.startsWith(url, 'http') || _.startsWith(url, 'https')) {
            return url;
        } else {
            return baseHost + (_.startsWith(url, '/') ? '' : '/') + url;
        }
    } else {
        return url;
    }
}
//------扩展生命周期逻辑----------
var onWillReceivePropsExt = function onWillReceivePropsExt(nextProps) {
    if ('uiParams' in nextProps || 'uiParser' in nextProps || 'uiEvent' in nextProps || 'uiMeta' in nextProps) {
        //重新合并二开扩展的js插件事件代码
        JsPluginUtils.merge({ page: this, uiEvent: this.state.uiEvent });
    }
};
var onWillMountExt = function onWillMountExt() {
    //初始化二开扩展的js插件代码
    JsPluginUtils.merge({ page: this, uiEvent: this.state.uiEvent });
};
//--------------------------------
var YYCreateView = React.createClass({
    displayName: 'YYCreateView',

    statics: {
        RUN_MODE_RUNTIME: 'runtime', //运行态
        RUN_MODE_DESIGN: 'design' //设计态
    },
    getDefaultProps: function getDefaultProps() {
        return {
            appCode: null,
            pageCode: null,
            billTypeCode: null,
            jsPluginUrl: null, //二开扩展的js代码文件路径
            uiMeta: null, //UI元数据
            uiParser: null, //UI组件解析器{"ComponentName":Component,...}
            uiEvent: null, //UI事件处理器{"uikey":{"eventName":Function,...},...}
            uiParams: null, //UI参数解析器{"ParamName":Function,...}
            uiRunMode: "runtime", //运行模式，默认为运行态-"runtime"，设计态-"design"
            technicalType: "icop", //应用类型，icop、ncc
            //--------------------------------------
            baseHost: ADDR, //缺省的域名地址
            onCreateParser: defaultCustomParser, //自定义动态注册视图解析器
            onViewAuthValidate: defaultViewAuthValid, //视图权限校验的回调函数
            globalParser: DefaultParser, //全局缺省视图解析器
            globalEvent: DefaultHandler, //全局缺省事件解析器
            globalParams: DefaultParams, //全局缺省参数解析器
            globalActions: DefaultActions, //全局缺省动作解析器
            onWillReceiveProps: onWillReceivePropsExt, //可扩展生命周期逻辑-WillReceiveProps
            onWillMount: onWillMountExt, //可扩展生命周期逻辑-WillMount
            onWillUpdate: null, //可扩展生命周期逻辑-WillUpdate
            onDidMount: null, //可扩展生命周期逻辑-DidMount
            onDidUpdate: null //可扩展生命周期逻辑-DidUpdate
        };
    },
    getInitialState: function getInitialState() {
        var uiParams = this._processUIParams(this.props.uiParams);
        var uiParser = this._processUIParser(this.props.uiParser);
        var uiEvent = this._processUIEvent(this.props.uiEvent);
        var uiMeta = this._processUIMeta(this.props.uiMeta);
        return {
            uiParams: uiParams, uiMeta: uiMeta, uiParser: uiParser, uiEvent: uiEvent,
            refreshTime: 0 //记录刷新次数
        };
    },
    componentWillReceiveProps: function componentWillReceiveProps(nextProps) {
        if ('uiParams' in nextProps || 'uiParser' in nextProps || 'uiEvent' in nextProps || 'uiMeta' in nextProps) {
            var uiParams = this._processUIParams(nextProps.uiParams);
            var uiParser = this._processUIParser(nextProps.uiParser);
            var uiEvent = this._processUIEvent(nextProps.uiEvent);
            var uiMeta = this._processUIMeta(nextProps.uiMeta);
            this.setState({
                uiParams: uiParams, uiMeta: uiMeta, uiParser: uiParser, uiEvent: uiEvent,
                refreshTime: this.state.refreshTime + 1
            });
        }
        if (typeof this.props.onWillReceiveProps == 'function') {
            this.props.onWillReceiveProps.call(this, nextProps);
        }
    }
    //性能优化，只有当refreshTime发生变更时才触发执行render方法
    ,
    shouldComponentUpdate: function shouldComponentUpdate(nextProps, nextState) {
        return this.state.refreshTime !== nextState.refreshTime;
    },
    componentWillMount: function componentWillMount() {
        //console.log('YYCreateView will mount');
        var _state = this.state,
            uiMeta = _state.uiMeta,
            uiEvent = _state.uiEvent;

        this._callEvent('onViewWillMount', { uiMeta: uiMeta, uiEvent: uiEvent });
        if (typeof this.props.onWillMount == 'function') {
            this.props.onWillMount.call(this);
        }
    },
    componentDidMount: function componentDidMount() {
        //console.log('YYCreateView did mount');
        var _state2 = this.state,
            uiMeta = _state2.uiMeta,
            uiEvent = _state2.uiEvent;

        var page = this; //注意eval里面会使用到此变量
        //运行逻辑公式
        if (uiMeta && uiMeta.logicFormula) {
            try {
                var runTime = [];
                runTime.push("this._logicFormulaRunTime = function(yy){");
                // runTime.push("console.log('yy-->',this,yy);");
                runTime.push(uiMeta.logicFormula);
                runTime.push("};");
                runTime.push("this._logicFormulaRunTime({page:page});");
                var jsCodeStr = runTime.join("");
                console.log('------运行代码-----');
                console.log(jsCodeStr);
                eval(jsCodeStr);
            } catch (e) {
                console.error('逻辑公式运行出错', e);
            }
        }
        this._callEvent('onViewDidMount', { uiMeta: uiMeta, uiEvent: uiEvent });
        if (typeof this.props.onDidMount == 'function') {
            this.props.onDidMount();
        }
    },
    componentWillUpdate: function componentWillUpdate(nextProps, nextState) {
        //console.log('YYCreateView will update');
        var uiMeta = nextState.uiMeta,
            uiEvent = nextState.uiEvent;

        this._callEvent('onViewWillUpdate', { uiMeta: uiMeta, uiEvent: uiEvent });
        if (typeof this.props.onWillUpdate == 'function') {
            this.props.onWillUpdate(nextProps, nextState);
        }
    },
    componentDidUpdate: function componentDidUpdate(prevProps, prevState) {
        //console.log('YYCreateView did update');
        var uiMeta = prevState.uiMeta,
            uiEvent = prevState.uiEvent;

        this._callEvent('onViewDidUpdate', { uiMeta: uiMeta, uiEvent: uiEvent });
        if (typeof this.props.onDidUpdate == 'function') {
            this.props.onDidUpdate(prevProps, prevState);
        }
    },
    childContextTypes: {
        findUI: React.PropTypes.func
    },
    getChildContext: function getChildContext() {
        return {
            findUI: this.findUI
        };
    }
    //回调指定的事件
    ,
    _callEvent: function _callEvent(eventName, _ref) {
        var uiMeta = _ref.uiMeta,
            uiEvent = _ref.uiEvent;

        if (!uiMeta || !uiEvent) return;
        for (var uikey in uiEvent) {
            var itemEvents = uiEvent[uikey];
            if (itemEvents && _.isFunction(itemEvents[eventName])) {
                var itemUI = this._findUI({ uiMeta: uiMeta, uikey: uikey }); //匹配到组件才调用事件
                if (itemUI) {
                    try {
                        var _itemUI = itemEvents[eventName].call(this, { uiMeta: uiMeta, item: itemUI });
                        if (_itemUI) itemUI = _itemUI;
                    } catch (err) {
                        console.error('[事件回调失败]' + uikey + '.' + eventName, err);
                    }
                }
            }
        }
    }
    //环境参数助手方法
    , _processUIParams: function _processUIParams(uiParams) {
        var _uiParams = _.assign({}, this.props.globalParams || {}, uiParams);
        for (var key in _uiParams) {
            var param = _uiParams[key];
            if (_.isFunction(param)) {
                //处理函数类型的动态参数
                _uiParams[key] = param.call(this);
            }
        }
        return _uiParams;
    }
    //元数据助手方法
    , _processUIMeta: function _processUIMeta(uiMeta) {
        var _uiMeta = uiMeta;
        return _uiMeta;
    }
    //解析器助手方法
    , _processUIParser: function _processUIParser(uiParser) {
        var _uiParser = _.assign({}, this.props.globalParser || {}, uiParser);
        return _uiParser;
    }
    //事件助手方法
    , _processUIEvent: function _processUIEvent(uiEvent) {
        //注意此次需要克隆，以防止引用共享
        var copyDefault = this.props.globalEvent ? _.cloneDeep(this.props.globalEvent) : {};
        var copyUiEvent = _.cloneDeep(uiEvent);
        var _uiEvent = _.assign(copyDefault, copyUiEvent);
        for (var uikey in _uiEvent) {
            var itemEvents = _uiEvent[uikey];
            for (var name in itemEvents) {
                try {
                    itemEvents[name] = itemEvents[name].bind(this);
                } catch (err) {
                    console.error('[绑定事件失败]' + uikey + '.' + name + ',检查是否为有效的Function', err);
                }
            }
        }
        return _uiEvent;
    }
    /**
     * 执行多个表单的验证
     * @param options{
     *  formKeys:[]  //需要进行验证的表单键值集合
     *  keepAll:true //当设置为false时，验证过程中任意一表单存在错误则不再继续进行验证
     *  success:null //所有表单都验证通过时触发的回调
     *  error:null   //keepAll=true时，所有表单验证后存在错误则触发回调；keepAll=false时，当任意一个表单验证不通过时触发回调；
     * }
     */
    , validateForms: function validateForms(options) {
        var page = this;

        var _$assign = _.assign({
            formKeys: [],
            keepAll: true,
            _index: 0,
            formValues: {},
            formErrors: {},
            success: null,
            error: null
        }, options),
            formKeys = _$assign.formKeys,
            keepAll = _$assign.keepAll,
            _index = _$assign._index,
            formValues = _$assign.formValues,
            formErrors = _$assign.formErrors,
            success = _$assign.success,
            error = _$assign.error;

        if (_index >= formKeys.length) {
            // 所有表单校验完毕
            if (_.isEmpty(formErrors)) {
                if (_.isFunction(success)) success({ formValues: formValues });
            } else {
                if (_.isFunction(error)) error({ formErrors: formErrors, formValues: formValues });
            }
            return;
        }
        var formKey = formKeys[_index];
        var form = page.findUI(formKey);
        if (form && form.api && form.api.validateFields) {
            form.api.validateFieldsAndScroll(function (errors, values) {
                formValues[formKey] = values;
                if (!!errors) {
                    //验证失败
                    formErrors[formKey] = errors;
                    if (keepAll === true) {
                        //任意表单出错任继续验证
                        page.validateForms(_.assign(options, { formValues: formValues, formErrors: formErrors, keepAll: keepAll, _index: _index + 1 }));
                    } else {
                        //任意表单出错则终止
                        if (_.isFunction(error)) {
                            error({ formErrors: formErrors, formValues: formValues, formKey: formKey, formIndex: _index });
                        }
                        return;
                    }
                } else {
                    //验证通过，则继续验证
                    page.validateForms(_.assign(options, { formValues: formValues, formErrors: formErrors, keepAll: keepAll, _index: _index + 1 }));
                }
            });
        }
    }
    /**
     * 刷新重绘页面
     */
    , refresh: function refresh(callback, state) {
        this.setState(_.assign({ refreshTime: this.state.refreshTime + 1 }, state), callback);
    }
    /**
     * 获取当前页面
     */
    , getPage: function getPage() {
        var that = this;
        return that;
    }
    /**
     * 获取应用编码
     */
    , getAppCode: function getAppCode() {
        return this.props.appCode;
    }
    /**
     * 获取页面编码
     */
    , getPageCode: function getPageCode() {
        return this.props.pageCode;
    }
    /**
    * 获取页面单据类型
    */
    , getBillTypeCode: function getBillTypeCode() {
        return this.props.billTypeCode;
    }
    /**
     * 获取页面应用类型
     */
    , getTechnicalType: function getTechnicalTyep() {
        return this.props.technicalType;
    }
    /**
    * 获取扩展的js插件文件路径
    */
    , getJsPluginUrl: function getJsPluginUrl() {
        var format = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : true;

        return format ? formatUrlPath(this.props.jsPluginUrl) : this.props.jsPluginUrl;
    }
    // /**
    //  * 启用页面加载遮罩功能（页面初始化的时候启用一次即可，后续即可直接使用setLoading控制遮罩层的显示状态。）
    //  */
    // ,enableLoading:function(){
    // }
    // /**
    //  * 禁用页面加载遮罩功能
    //  */
    // ,disabledLoading:function(){
    // }
    // /**
    //  * 设置页面遮罩层的加载状态（注意：必须手动调用一次启用enableLoading才会生效）
    //  * @param status
    //  * @param refresh
    //  */
    // ,setLoading:function(status=false,refresh=true){
    // }
    /**
     * 路由到指定页面
     * @param url   路由路径
     * @param query URL附加的参数（显示参数）
     * @param state 路由附加的参数（隐藏参数）
     */
    , routeTo: function routeTo(url, query, state) {
        if (!this.props.router) {
            console.error('调用routeTo失败,router不存在');return;
        }
        var location = {};
        if (url) location.pathname = url;
        if (query) location.query = query;
        if (state) location.state = state;
        //this.props.history.push(url,_params);
        // this.props.history.push(location);
        this.props.router.push(location); // Router版本升级修改
    }
    /**
     * 获取路由传递的参数值（隐藏参数）
     */
    , getRouteParams: function getRouteParams() {
        if (!this.props.location && !this.props.params) {
            console.error('调用getRouteParams失败,location和params均不存在');return;
        }
        return _.isEmpty(this.props.location.state) ? _.isEmpty(this.props.params) ? null : this.props.params : this.props.location.state;
    }
    /**
     * 获取路由传递的URL参数值（直接链接在URL的?后面的参数列表）（显示参数）
     */
    , getRouteQuery: function getRouteQuery() {
        if (!this.props.location) {
            console.error('调用getRouteQuery失败,location不存在');return;
        }
        return _.isEmpty(this.props.location.query) ? null : this.props.location.query;
    }
    /**
     * 后退上一个页面
     */
    , goBack: function goBack() {
        if (!this.props.router) {
            console.error('调用goBack失败,router不存在');return;
        }
        this.props.router.goBack();
    }
    /**
     * 前进下一个页面
     */
    , goForward: function goForward() {
        if (!this.props.router) {
            console.error('调用goForward失败,router不存在');return;
        }
        this.props.router.goForward();
    }
    /**
     * 后退或前进到第N个页面
     * @param to n为正数则为前进，n为负数则为后退
     */
    , goTo: function goTo(to) {
        if (!this.props.router) {
            console.error('调用goTo失败,router不存在');return;
        }
        this.props.router.go(to);
    }
    /**
     * 通过键值查找UI对象模型
     * @param uikey
     */
    , findUI: function findUI(uikey) {
        if (this.state.uiMeta) {
            var result = this._findUI({ uiMeta: this.state.uiMeta, uikey: uikey });
            if (!result) console.warn('[api.findUI]找不到：' + uikey);
            return result;
        }
        return null;
    },
    _findUI: function _findUI(options) {
        var uiMeta = options.uiMeta,
            uikey = options.uikey;

        var _uiMeta = _.isArray(uiMeta) ? uiMeta : [uiMeta];
        var results = TreeUtils.findWithPropName(_uiMeta, 'uikey', uikey, true, true);
        if (results && results.length > 0) {
            results[0].api = this._findByRef(results[0].nid); //扩展API对象
            return results[0];
        }
        return null;
    }
    /**
     * 通过类型查找UI数据模型
     * @param uitype 解析器名称
     * @param options {
     *     loop 默认：true，是否递归遍历子集合
     *     only 默认：false，是否匹配到第一个就终止
     * }
     */
    , findUIByType: function findUIByType(uitype, options) {
        var opts = _.assign({ loop: true, only: false }, options);
        if (this.state.uiMeta) {
            var _uiMeta = _.isArray(this.state.uiMeta) ? this.state.uiMeta : [this.state.uiMeta];
            var results = TreeUtils.findWithPropName(_uiMeta, 'uitype', uitype, opts.loop, opts.only);
            if (results && results.length > 0) {
                var that = this;
                _.forEach(results, function (item, index) {
                    results[index].api = that._findByRef(item.nid); //扩展API对象
                });
                return results;
            }
        }
        return null;
    }
    //ref值指向nid值
    , _findByRef: function _findByRef(ref) {
        //TODO 目前存在缺陷，在折叠卡片页签第一次未展开时，无法通过refs获取内部组件
        return ref && this.refs[ref] ? this.refs[ref] : null;
    }
    /**
     * 通过键值查找UI组件实例
     * @param uikey
     */
    , findComp: function findComp(uikey) {
        if (this.state.uiMeta) {
            var _uiMeta = _.isArray(this.state.uiMeta) ? this.state.uiMeta : [this.state.uiMeta];
            var results = TreeUtils.findWithPropName(_uiMeta, 'uikey', uikey, true, true);
            return this._findByRef(results.length > 0 ? results[0].nid : null);
        }
        return null;
    }
    //环境参数替换
    , _processParams: function _processParams(node) {
        var uiParams = this.state.uiParams;
        if (_.isEmpty(uiParams)) return;
        if (!node) return;
        var keys = [];
        //过滤出包含运行参数的属性
        for (var key in node) {
            var value = node[key];
            if (value && _.isString(value) && hasParamPatten(value)) {
                keys.push(key);
            };
        }
        //进行运行参数替换
        if (keys.length == 0) return;
        for (var idx in keys) {
            var propName = keys[idx];
            var propValue = node[propName];
            if (!propValue) break;
            for (var paramKey in uiParams) {
                node[propName] = propValue.replace(new RegExp('!\{' + paramKey + '}', 'gm'), uiParams[paramKey]);
                if (!hasParamPatten(node[propName])) break; //性能优化，如果替换一次后，就不存在需要替换的参数则跳过本次。
            }
        }
    }
    //获取解析后的视图
    , _getViewContent: function _getViewContent(options) {
        //console.log('第'+this.state.refreshTime+'次进行视图解析');
        var uiMeta = options.uiMeta,
            uiEvent = options.uiEvent,
            uiParser = options.uiParser;

        var views = null;
        if (uiMeta) {
            if (_.isArray(uiMeta)) {
                views = this._processViews(uiMeta, uiEvent, uiParser);
            } else {
                views = this._processViews([uiMeta], uiEvent, uiParser);
            }
        }
        if (views && views.length > 0) {
            return _.isArray(uiMeta) ? views : views[0];
        } else {
            return null;
        }
    }
    //解析视图
    , _processViews: function _processViews(items, uiEvent, uiParser) {
        if (!_.isArray(items)) return null;
        var views = [];
        var _props = this.props,
            uiRunMode = _props.uiRunMode,
            onCreateParser = _props.onCreateParser,
            globalActions = _props.globalActions,
            appCode = _props.appCode,
            pageCode = _props.pageCode,
            billTypeCode = _props.billTypeCode;

        var that = this;
        for (var i = 0; i < items.length; i++) {
            var itemUI = items[i];
            if (!itemUI || _.isEmpty(itemUI)) continue;
            //解析子视图
            var childView = itemUI.children;
            var doEachChild = _.isArray(itemUI.children);
            if (doEachChild) {
                childView = this._processViews(itemUI.children, uiEvent, uiParser);
            }
            //解析视图事件
            var itemEvents = null;
            if (itemUI.uikey && uiEvent) {
                itemEvents = uiEvent[itemUI.uikey];
            }
            //解析事件动作
            if (itemUI.uievents) {
                if (!itemEvents) itemEvents = {};
                //解析绑定的所有事件
                _.forEach(itemUI.uievents, function (uiactions, uievent) {
                    //解析对应事件下的动作列表
                    itemEvents[uievent] = function (ui, event, actions) {
                        for (var actSeq = 0; actSeq < actions.length; actSeq++) {
                            var action = actions[actSeq];
                            //获取动作函数
                            var actionFunc = globalActions ? globalActions[action.uiaction] : null;
                            //执行动作处理
                            if (typeof actionFunc == 'function') {
                                actionFunc.call(this, { event: event, action: action, ui: ui });
                            }
                        }
                    }.bind(that, itemUI, uievent, uiactions);
                });
            }
            ////解析前的回调事件
            //if(itemEvents&&_.isFunction(itemEvents['onParserBefore'])){
            //    var _itemUI = itemEvents['onParserBefore'].call(that,itemUI);
            //    if(_itemUI)itemUI = _itemUI;
            //}
            //解析当前组件
            var UIComponent = null;
            if (typeof onCreateParser == 'function') {
                UIComponent = onCreateParser({ item: itemUI });
            }
            if (!UIComponent) {
                UIComponent = itemUI.uitype ? uiParser[itemUI.uitype] : null;
            }

            //清理掉API对象
            delete itemUI.api;
            //当前组件属性
            var itemProps = _.assign({
                //为所有组件追加uiorigin属性，本属性提供了界面设计器解析构建页面时的特有属性
                uiorigin: { appCode: appCode, pageCode: pageCode, billTypeCode: billTypeCode }
            }, itemUI);
            //环境参数替换
            this._processParams(itemProps);
            //标识运行模式
            if (uiRunMode) itemProps.uiRunMode = uiRunMode;
            //添加到视图集合，当uidisabled==true时，则不进行组件解析，返回原始数据。
            if (itemUI.uidisabled == true) {
                //不进行组件解析
                views.push(itemProps);
            } else if (UIComponent) {
                //存在相关组件解析器
                //将当前UI元数据绑定到组件的ui属性
                var privateProps = {};
                if (itemUI.nid) {
                    privateProps.ref = itemUI.nid;
                    if (!itemUI.key) {
                        privateProps.key = pageCode + "_" + itemUI.nid;
                    }
                }
                var itemViewProps = _.assign({}, itemProps, privateProps, itemEvents);
                var itemView = null;
                //处理视图是否拥有权限
                var authInfo = this.isHasAuthorityView({ item: itemUI, appCode: appCode, pageCode: pageCode });
                if (authInfo.enable) {
                    //已授权权限
                    itemView = React.createElement(UIComponent, itemViewProps, childView);
                } else {
                    //未授权权限
                    if (authInfo.viewMode == 'disabled') {
                        //未授权时显示为禁用
                        itemViewProps.roleDisabled = true;
                        itemView = React.createElement(UIComponent, itemViewProps, childView);
                    } else {
                        //未授权时不显示
                        itemView = null;
                    }
                }
                if (itemView) views.push(itemView);
                //var itemView= <UIComponent {...itemProps} ref={itemUI.nid} key={itemKey} {...itemEvents} children={childView} />;
                ////解析后的回调事件
                //if(itemEvents&&_.isFunction(itemEvents['onParserAfter'])){
                //    var _itemView = itemEvents['onParserAfter'].call(that,itemUI,itemView);
                //    if(_itemView)itemView = _itemView;
                //}
            } else {
                //不存在相关组件解析器则返回包含元数据的空视图组件
                var emptyView = React.createElement(EmptyView, itemProps);
                views.push(emptyView);
            }
        }
        return views;
    }
    //指定uikey键值的视图组件是否有权限
    , isHasAuthorityView: function isHasAuthorityView(options) {
        //enable-是否有授权权限、viewMode-当没有权限时的显示方式
        if (typeof this.props.onViewAuthValidate == 'function') {
            return this.props.onViewAuthValidate(options);
        } else {
            return { enable: true, viewMode: 'hidden' };
        }
    },
    render: function render() {
        var _state3 = this.state,
            uiMeta = _state3.uiMeta,
            uiParser = _state3.uiParser,
            uiEvent = _state3.uiEvent;
        //获取解析后的视图

        var viewContent = this._getViewContent({ uiMeta: uiMeta, uiParser: uiParser, uiEvent: uiEvent });
        return viewContent;
    }
});
module.exports = YYCreateView;