'use strict';

require('./intro.css'); //注意放门户下时要移除本行代码
var INTRO_STATIC_URL = 'https://static.yonyouccs.com/intro/';
var INTRO_STATIC_IMAGES = {
    'menhu': ['intro_menhu1.jpg', 'intro_menhu2.jpg'], //介绍门户工作台
    'hetong_list': ['intro_hetong1.jpg', 'intro_hetong2.jpg'], //介绍合同台账列表
    'hetong_view': ['intro_hetong3.jpg'] //介绍合同查看页面
};
var IntroUtils = {
    _currStep: 0,
    //显示特定场景的新手介绍
    showIntroScene: function showIntroScene(options) {
        var opts = options || {};
        var code = opts.code;
        var icopContext = IntroUtils.getCookie('icop_context');
        var jsTxt = void 0;
        var jsonObj = void 0;
        if (icopContext) {
            //应用层获取上下文的cookie键值
            jsTxt = '(' + decodeURIComponent(icopContext.replace(/'/, "\'")) + ')';
            jsonObj = eval(jsTxt); //转换为JSON对象
        } else {
            //门户层获取上下文的cookie键值
            jsonObj = { _A_P_userLoginName: IntroUtils.getCookie('_A_P_userLoginName') };
        }
        var currUserName = jsonObj["_A_P_userLoginName"];
        var doneStatus = window.sessionStorage ? window.sessionStorage["yyui_intro_status_" + code] : false; //当前session是否已介绍完成
        if (doneStatus === 'done') return;
        //当前登录的用户名包含（"chanpin"或"xinshou"）
        if (currUserName && (currUserName.indexOf('yanshi') >= 0 || currUserName.indexOf('xinshou') >= 0)) {
            var images = INTRO_STATIC_IMAGES[code];
            IntroUtils.showIntro({ images: images,
                //当前session标记已介绍完成
                onDone: function onDone() {
                    window.sessionStorage.setItem("yyui_intro_status_" + code, "done");
                }
            });
        }
    },
    //显示新手介绍
    showIntro: function showIntro(options) {
        var opts = options || {};
        var images = opts.images || [];
        var step = opts.step;
        var onDone = opts.onDone;
        if (!images || !images.length) {
            console.log('images参数不能为空');return;
        }
        IntroUtils._currStep = step !== undefined ? step : 0;
        IntroUtils._createIntroBox();
        var imgDom = document.getElementById('yyui_intro_image_id');
        imgDom.setAttribute("src", INTRO_STATIC_URL + images[IntroUtils._currStep]);
        var buttonDom = document.getElementById('yyui_intro_button_id');
        buttonDom.innerText = IntroUtils._currStep + 1 < images.length ? '下一步' : '我知道了';
        buttonDom.onclick = function () {
            if (IntroUtils._currStep + 1 < images.length) {
                //下一步
                IntroUtils.showIntro({ images: images, onDone: onDone, step: IntroUtils._currStep + 1 });
            } else {
                //我知道了
                IntroUtils.hideIntro();
                if (typeof onDone == 'function') {
                    onDone();
                }
            }
        };
        //显示新手介绍
        if (!document.body.classList.contains('yyui-intro-body')) document.body.classList.add('yyui-intro-body');
    },
    //关闭新手介绍
    hideIntro: function hideIntro() {
        document.body.classList.remove('yyui-intro-body');
    },
    /**
     * 构建新手介绍的html结构
     * <div class="yyui-intro-box">
     *  <img class="yyui-intro-image" src="./build/intro1.jpg"></img>
     *  <div class="yyui-intro-toolbar"><span class="yyui-intro-button">我知道了</span></div>
     * </div>
     * @return {Element}
     * @private
     */
    _createIntroBox: function _createIntroBox() {
        var div = document.getElementById("yyui_intro_box_id");
        if (div) return div;
        //容器
        var divBox = document.createElement("div");
        divBox.setAttribute("id", "yyui_intro_box_id");
        divBox.setAttribute("class", "yyui-intro-box");
        //图片
        var divImg = document.createElement("img");
        divImg.setAttribute("id", "yyui_intro_image_id");
        divImg.setAttribute("class", "yyui-intro-image");
        //工具栏
        var divToolbar = document.createElement("div");
        divToolbar.setAttribute("id", "yyui_intro_box_id");
        divToolbar.setAttribute("class", "yyui-intro-toolbar");
        //按钮
        var divButton = document.createElement("span");
        divButton.setAttribute("id", "yyui_intro_button_id");
        divButton.setAttribute("class", "yyui-intro-button");
        divToolbar.appendChild(divButton);
        divBox.appendChild(divImg);
        divBox.appendChild(divToolbar);
        document.body.appendChild(divBox);
        return divBox;
    },
    // 取cookies函数
    getCookie: function getCookie(name) {
        var arr = document.cookie.match(new RegExp("(^| )" + name + "=([^;]*)(;|$)"));
        if (arr != null) return decodeURIComponent(arr[2]);
        return null;
    }
};

module.exports = IntroUtils; //注意放门户下时要移除本行代码