"use strict";

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports.preventDefaultEvent = preventDefaultEvent;
exports.toArray = toArray;
exports.checkValueTypeAndValue = checkValueTypeAndValue;
exports.getObjectValuePropValue = getObjectValuePropValue;
exports.getValuePropValue = getValuePropValue;
exports.getPropValue = getPropValue;
exports.getLabelByValue = getLabelByValue;
exports.findIndexInValueByKey = findIndexInValueByKey;
exports.getSelectKeys = getSelectKeys;
exports.addLabelToValue = addLabelToValue;
exports.generateMenuItem = generateMenuItem;
exports.getSearchParams = getSearchParams;
exports.getDataByReferCode = getDataByReferCode;
exports.requestSearchData = requestSearchData;
exports.requestCreateData = requestCreateData;
var _ = require('lodash');
var React = require('react');
var YYMenuItem = require('../../menu/YYMenuItem');
var YYMessage = require('../../message/YYMessage');
var Ajax = require('../../../utils/ajax');

/**
 * 防止默认事件
 */
function preventDefaultEvent(e) {
    e.preventDefault();
}

/**
 * 转换成数组
 */
function toArray(value) {
    var ret = value;
    if (value === undefined) {
        ret = [];
    } else if (!Array.isArray(value)) {
        ret = [value];
    }
    return ret;
}

/**
 * 检查value与valueType是否匹配
 */
function checkValueTypeAndValue(props) {
    if (props.valueType && props.value && (props.valueType === 'object' && !_.isObject(props.value) || props.valueType === 'string' && !_.isString(props.value))) throw new Error('valueType is ' + props.valueType);
}

/**
 * 获取对象类型的节点值
 */
function getObjectValuePropValue(child, keyField) {
    var props = child.props;
    if (props) {
        return {
            id: props[keyField.idField],
            code: props[keyField.codeField],
            name: props[keyField.nameField]
        };
    }
    throw new Error('no props for ' + child);
}

/**
 * 获取字符类型的节点值
 */
function getValuePropValue(child) {
    var props = child.props;
    if ('value' in props) {
        return props.value;
    }
    if (child.key) {
        return child.key;
    }
    throw new Error('no key or value for ' + child);
}

/**
 * 获取节点某个属性值
 */
function getPropValue(child) {
    var prop = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'children';

    if (prop === 'value') {
        return getValuePropValue(child);
    }
    return child.props[prop];
}

/**
 * 获取节点标签值
 */
function getLabelByValue(children, value) {
    if (value === undefined) {
        return null;
    }
    var label = null;
    React.Children.forEach(children, function (child) {
        if (getValuePropValue(child) === value) {
            label = getPropValue(child);
        }
    });
    if (label === null) {
        return value;
    }
    return label;
}

function findIndexInValueByKey(value, key) {
    var index = -1;
    for (var i = 0; i < value.length; i++) {
        if (value[i].key === key) {
            index = i;
            break;
        }
    }
    return index;
}

function getSelectKeys(menuItems, value) {
    if (value === null || value === undefined) {
        return [];
    }
    var selectedKeys = [];
    React.Children.forEach(menuItems, function (item) {
        var itemValue = getValuePropValue(item);
        var itemKey = item.key;
        if (findIndexInValueByKey(value, itemValue) !== -1 && itemKey) {
            selectedKeys.push(itemKey);
        }
    });
    return selectedKeys;
}

/**
 * 整理值为对象
 */
function addLabelToValue(props, value_) {
    var value = value_;
    value = value.map(function (v) {
        return {
            key: v,
            label: getLabelByValue(props.children, v)
        };
    });
    return value;
}

/**
 * 生成菜单项
 * @param options 下拉项数据集合
 * @param renderItemText 自定义下拉项显示文本
 */
function generateMenuItem(options, renderItemText) {
    var keyField = this.state.keyField;

    return _.map(options, function (option) {
        var key = option.key,
            label = option.label;

        var keyValue = key ? key : option[keyField.idField];
        var itemText = label ? label : option[keyField.nameField];
        if (typeof renderItemText == 'function' && !option['newAddRefer']) {
            //注意：排除内置的新增下拉项
            var returnText = renderItemText(option, itemText);
            if (returnText !== null && returnText !== undefined) itemText = returnText;
        }
        return React.createElement(
            YYMenuItem,
            _extends({}, option, { key: keyValue, value: keyValue }),
            itemText
        );
    });
}

/**
 * 请求参照接口参数
 * @param value
 * @returns {{condition: null, searchText: null, maxSize: number}}
 */
function getSearchParams(value) {
    var queryData = {
        condition: null,
        searchText: null,
        maxSize: this.props.maxSize ? parseInt(this.props.maxSize) : 20
    };
    var _condition = Ajax.getParams(this.props.condition);
    if (!_.isEmpty(_condition) && _.isPlainObject(_condition)) {
        //转成JSON格式字符串
        queryData.condition = JSON.stringify(_condition);
    }
    queryData.searchText = value.searchText;
    if (_.isFunction(this.props.onSearchParams)) {
        queryData = this.props.onSearchParams(queryData);
    }
    return queryData;
}

/**
 * 获取参照接口参数
 * @param refinfokey
 * @param url
 */
function getDataByReferCode(refinfokey, url) {
    var _this = this;
    var autoSearch = this.state.autoSearch;

    var queryData = { refCode: refinfokey };
    if (!refinfokey) {
        console.warn("参照code不能为空");
    } else {
        Ajax.request({
            method: 'GET',
            url: url,
            query: queryData,
            type: 'json',
            success: function success(data) {
                if (data && data.data) {
                    var idField = "id";
                    var codeField = "code";
                    var nameField = "name";
                    if (data.data.idField != null && data.data.idField !== "") {
                        idField = data.data.idField;
                    }
                    if (data.data.codeField != null && data.data.codeField !== "") {
                        codeField = data.data.codeField;
                    }
                    if (data.data.nameField != null && data.data.nameField !== "") {
                        nameField = data.data.nameField;
                    }
                    _this.state.dataUrl = data.data.dataurl;
                    _this.state.createUrl = data.data.createurl;
                    _this.state.keyField = { idField: idField, codeField: codeField, nameField: nameField };
                    if (autoSearch) {
                        _this.state.autoSearch = false;
                        _this.requestSearchData('', _this.state.dataUrl, _this.getSearchParams, true);
                    }
                }
            },
            error: function error(data) {
                YYMessage.error("根据参照code查询失败！");
                console.error("根据参照code查询失败！");
            }
        });
    }
}

/**
 * 请求参照接口
 * @param searchText
 * @param searchUrl
 * @param onSearchParams
 * @param initSearch
 */
function requestSearchData(searchText, searchUrl, onSearchParams, initSearch) {
    var _this = this;
    var _props = this.props,
        autoOne = _props.autoOne,
        onChange = _props.onChange,
        onDealData = _props.onDealData,
        onCreateNew = _props.onCreateNew,
        renderNewText = _props.renderNewText;
    var _state = this.state,
        createUrl = _state.createUrl,
        inputValue = _state.inputValue,
        focus = _state.focus;

    var preSearchTime = this.searchTime;
    if (searchUrl) {
        var _searchParams = _.assign({ searchText: searchText });
        if (typeof onSearchParams == 'function') {
            _searchParams = onSearchParams(_searchParams, this);
        }
        Ajax.getJSON(searchUrl, _searchParams, function (result) {
            var resultItems = [];
            if (result && result.success) {
                resultItems = result.backData;
                if (_.isFunction(onDealData)) {
                    //这块有问题
                    //backResult：查询成功返回的数据
                    //searchText：输入框显示文本
                    //createurl：新建选项url
                    //textKey：下拉选项显示的属性
                    //valueKey：文本框显示的属性
                    var dealDataOptions = {};
                    dealDataOptions.backData = resultItems;
                    dealDataOptions.searchText = searchText;
                    dealDataOptions.createurl = createUrl;
                    resultItems = onDealData(dealDataOptions);
                }
                var value = _.find(result.backData || [], [_this.state.keyField.nameField, searchText]);
                if (!value && (createUrl || onCreateNew)) {
                    var item = {};
                    var newReferText = '新建-' + searchText;
                    if (_.isFunction(renderNewText)) {
                        newReferText = renderNewText(searchText);
                    }
                    item['label'] = newReferText;
                    item['newAddRefer'] = true;
                    item['searchText'] = searchText;
                    resultItems.push(item);
                } else if (!value && result.backData <= 0) {
                    var _item = {};
                    _item['key'] = '暂无匹配内容';
                    _item['label'] = '暂无匹配内容';
                    _item.disabled = true;
                    resultItems.push(_item);
                }
            } else {
                YYMessage.error(result.backMsg);
            }
            var stateData = {
                options: resultItems,
                open: initSearch ? false : focus ? true : false
            };
            if (autoOne && resultItems.length == 1 && initSearch) {
                searchText = resultItems[0][_this.state.keyField.nameField];
                stateData['inputValue'] = searchText;
            }
            if (preSearchTime !== _this.searchTime) {
                return; //参照查询很慢的时候，丢弃上一次查询结果
            }
            _this.setState(stateData, function () {
                if (autoOne && initSearch && resultItems.length === 1 && !resultItems[0].disabled) {
                    onChange(_this.props.valueType === 'object' ? getObjectValuePropValue({ props: resultItems[0] }, _this.state.keyField) : searchText, resultItems[0], true);
                } else if (!initSearch && inputValue !== '') {
                    onChange(searchText, {}, false);
                }
            });
        });
    }
}

/**
 * 请求CreateURL
 * @param values
 */
function requestCreateData(values) {
    var _props2 = this.props,
        onSubmitSuccess = _props2.onSubmitSuccess,
        onSubmitFail = _props2.onSubmitFail;
    var createUrl = this.state.createUrl;

    Ajax.postJSON(createUrl, values, onSubmitSuccess, onSubmitFail);
}